@@ -11,7 +11,7 @@ def make_workspace(name):
     """
 
     if os.path.exists(name):
-        return f"Folder [{name}] is exists already, Please check out the work path"
+        raise TypeError(f"Folder [{name}] is exists already, Please check out the work path")
     else:
         templates = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'template')
         project = os.path.join(os.getcwd(), name)
@@ -23,12 +23,7 @@ def make_workspace(name):
     with open(os.path.join(project, 'config', 'configuration.ini'), "r", encoding='utf-8') as f:
         content = f.read()
     with open(os.path.join(project, 'config', 'configuration.ini'), "w", encoding='utf-8') as f:
-        content = content % (os.path.join(os.getcwd(), name),
-                             os.path.join(os.getcwd(), name, "data"),
-                             os.path.join(os.getcwd(), name, "data"),
-                             os.path.join(os.getcwd(), name, "result"),
-                             os.path.join(os.getcwd(), name, "log"),
-                             os.path.join(os.getcwd(), name, "result"))
+        content = content % (os.path.join(os.getcwd(), name))
         f.write(content)
 
 def main():
