@@ -5,10 +5,10 @@ from custom import Custom
 
 def main(**kwargs):
     """
-    项目训练程序入口
+    项目特征工程程序入口
     """
     # 加载数据、变量类型划分、特征集与标签列划分
-    data = mksc.load_data("pickle")
+    data = mksc.load_data()
     numeric_var, category_var, datetime_var, label_var = preprocess.get_variable_type()
     feature = data[numeric_var + category_var + datetime_var]
     label = data[label_var]
@@ -23,6 +23,7 @@ def main(**kwargs):
 
     # 自定义特征组合
     feature = Custom.feature_combination(feature)
+    feature.drop(datetime_var,  axis=1, inplace=True)
 
     # 标准化特征工程
     fe = FeatureEngineering(feature, label, **kwargs)
