@@ -1,15 +1,15 @@
 from statsmodels.iolib.smpickle import load_pickle
 import pandas as pd
 import mksc
-from mksc.feature_engineering import preprocess
 from mksc.model import training
+from mksc.feature_engineering import preprocess
 from mksc.feature_engineering import transform
 from custom import Custom
 
 def main(**kwargs):
-    feature_engineering = load_pickle('result/feature_engineering.pickle')
 
-    data = mksc.load_data("pickle")
+    feature_engineering = load_pickle('result/feature_engineering.pickle')
+    data = mksc.load_data()
     numeric_var, category_var, datetime_var, label_var = preprocess.get_variable_type()
     feature = data[numeric_var + category_var + datetime_var]
     label = data[label_var]
@@ -24,17 +24,12 @@ def main(**kwargs):
 
     # 自定义特征组合模块
     feature = Custom.feature_combination(feature)
+    feature.drop(datetime_var,  axis=1, inplace=True)
 
-    # One-Hot编码
-    category_var = feature.select_dtypes(include=['object']).columns
-    feature[category_var].fillna("NA", inplace=True)
-    if not feature[category_var].empty:
-        feature = pd.concat([feature, pd.get_dummies(feature[category_var])], axis=1)
-    feature.drop(category_var, axis=1, inplace=True)
-    feature = feature[feature_engineering['feature_selected']]
+    # 数据处理
+    feature = transform(feature, feature_engineering)
 
     # 模型训练
-    feature = transform(feature, feature_engineering)
     training(feature, label, **kwargs)
 
 
